@@ -1,5 +1,6 @@
 import matplotlib.pyplot as plt
 import os
+from os.path import basename
 import numpy as np
 import logging
 
@@ -85,6 +86,7 @@ class UavsarScene():
             sub_dir (str): sub-directory in working directory to put tiffs
             binary_dir (str): directory containing binary files. Autogenerated from unzipping.
         """
+        pols = ['VV','VH','HV','HH']
         if not binary_dir:
             if self.binary_fps:
                 binary_fps = self.binary_fps
@@ -99,12 +101,18 @@ class UavsarScene():
             os.makedirs(out_dir)
 
         if not ann_fp:
-            ann_fp = [a for a in binary_fps if '.ann' in a][0]
-            if not ann_fp:
+            ann_fps = [a for a in binary_fps if '.ann' in a]
+            ann_dic = {}
+            for pol in pols:
+                ann_dic[pol] = [fp for fp in ann_fps if pol in fp][0]
+            if not ann_fps:
                 log.warning('No annotation file found for binary files.')
 
         binary_img_fps = [f for f in binary_fps if '.ann' not in f]
+
         for f in binary_img_fps:
+            f_pol = [pol for pol in pols if pol in basename(f)][0]
+            ann_fp = ann_fps[f_pol]
             desc, array, type = grd_tiff_convert(f, out_dir, ann_fp = ann_fp, overwrite = True)
             self.images.append({'description': desc, 'array':  array, 'type': type})
 
